@@ -23,8 +23,9 @@ PATH=$OBJDIR:$PATH
 
 PSS_MKSCRIPTSDIR="${srcdir}"
 LIBEXECDIR="${OBJDIR}"
+PKGDIG_SYSCONFDIR="${OBJDIR}"
 
-export BMAKE AWKPATH PATH PSS_MKSCRIPTSDIR AWKPATH LIBEXECDIR
+export BMAKE AWKPATH PATH PSS_MKSCRIPTSDIR AWKPATH LIBEXECDIR PKGDIG_SYSCONFDIR
 
 #
 print_args (){
